/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef CALCULATEPOLAR_SRC_LAMINARTAW_LAMINARTAWCALCULATEPOLAR_H_
#define CALCULATEPOLAR_SRC_LAMINARTAW_LAMINARTAWCALCULATEPOLAR_H_

#include "laminarTAWConfig.h"
#include "HLFCStrategy.h"

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>
#include <moduleBasics/report.h>
#include <moduleBasics/plot.h>

#include <memory>
#include <vector>
#include <string>

class laminarTAWCalculatePolar : public Strategy {
 public:
    std::string polarXMLFilePath;          /**< Path to the polar XML output file, derived from the I/O file path */

    explicit laminarTAWCalculatePolar(std::shared_ptr<RuntimeIO> rtIO): rtIO_(rtIO), report_(rtIO) {}
    ~laminarTAWCalculatePolar() = default;
    void initialize();
    void run();
    void update();
    void report();
    void save();
    void selectAeroStrategy();

 private:
    std::shared_ptr<RuntimeIO> rtIO_; /*<-- RuntimeIO object*/
    std::shared_ptr<laminarTAWConfig> config_;
    std::shared_ptr<HLFCStrategy> myHLFCStrategy;
    Report report_; /*Report object*/
};

#endif  // CALCULATEPOLAR_SRC_LAMINARTAW_LAMINARTAWCALCULATEPOLAR_H_
