/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

 /* === Includes === */
#include <gtest/gtest.h>
#include <aixml/node.h>
#include <matplot/matplot.h>

/* Unit Under Test */
#include "constraint_analysis/ca_parser.h"
#include "constraint_analysis/ca_plotting.h"

TEST(ConstraintAnalysis_Plot, initialization)
{
    ConstraintAnalysis_Plot ca_plot();
};

TEST(ConstraintAnalysis_Plot, plotting)
{
    std::filesystem::path file{ CMAKE_TEST_STUBS_DIR };
    file /= "plot.svg";
    ConstraintAnalysis_Plot ca_plot;
    std::vector<double> x = { 0,1,2,3,4,5,6,7,8,9,10,11,12 };
    std::vector<double> y = { 0,1,2,3,4,5,6,5,4,3,2,1,0 };
    std::vector<double> z = { 6,5,4,3,2,1,0,1,2,3,4,5,6 };
    ca_plot.add_curve(x, y, "label 1");
    ca_plot.add_curve(x, z, "label 2");
    ca_plot.save_figure(file);
}; 

TEST(ConstraintAnalysis_Plot, constraint_plotting)
{
    std::filesystem::path file{ CMAKE_TEST_STUBS_DIR };
    file /= "ca_plot.svg";
    ConstraintAnalysis_Plot ca_plot;
    std::vector<double> W_over_S = { 10,20,30,40,50,60,70,80,90,100,110,120,130,140,150,160,170,180,190,200,210,220,230,240,250,260,270,280,290,300 };
    std::vector<double> case1 = {};
    std::vector<double> case2 = {};
    for (double W_S : W_over_S) {
        case1.push_back(0.9 / 0.97 * (0.047164 * 0.9 / (0.5 * 0.755 * 250.0 * 250.0) * W_S*30.0 - 0.00611 + 1.2 * 0.019369 / (0.9 / (0.5 * 1.225 * 250.0 * 250.0) * W_S * 30.0)));
        case2.push_back(0.9 / 0.8 * (0.047164 * 9.0 * 0.9 / (0.5 * 0.8 * 250 * 250)* W_S * 30.0 - 0.00611*3.0 + 1.2 * 0.019369 /((0.9 / (0.5 * 1.225 * 250.0 * 250.0) * W_S * 30.0))));
    }
    ca_plot.add_curve(W_over_S, case1, "Cruise");
    ca_plot.add_curve(W_over_S, case2, "3g Turn");
    ca_plot.save_figure(file);
};
