/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "../../../standard_strategy.h"
#include "../../../../toolinfo.h"
#include <vector>
#include <unitConversion/unitConversion.h>

void StandardStrategy::set_html_body_LCA_schaefer(const std::shared_ptr<RuntimeIO> &rtIO) {// cppcheck-suppress unusedFunction
        double total_CO2(0.);
        double total_HC(0.);
        double total_NOx(0.);
        double total_SO2(0.);
        double total_CO(0.);
        double total_H2O(0.);
        double total_CH4(0.);
        double total_PM10(0.);
        double total_N2O(0.);
        double total_PFC(0.);
        double total_NMVOC(0.);

        /* Table of Life cyle emissions */
        total_CO2 = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO2/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO2
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO2;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO2 > 0.)
                total_CO2 += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO2;

        total_HC = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.HC/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.HC
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.HC;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.HC > 0.)
                total_HC += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.HC;

        total_NOx = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.NOx/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.NOx
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.NOx;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NOx > 0.)
                total_NOx += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NOx;

        total_SO2 = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.SO2/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.SO2
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.SO2;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.SO2 > 0.)
                total_SO2 += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.SO2;

        total_CO = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO > 0.)
                total_CO += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO;

        total_H2O = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.H2O/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.H2O
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.H2O;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.H2O > 0.)
                total_H2O += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.H2O;

        total_CH4 = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CH4/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CH4
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CH4;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CH4 > 0.)
                total_CH4 += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CH4;

        total_PM10 = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.PM10/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.PM10
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.PM10;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PM10 > 0.)
                total_PM10 += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PM10;

        total_N2O = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.N2O/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.N2O
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.N2O;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.N2O > 0.)
                total_N2O += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.N2O;

        total_PFC = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.PFC/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.PFC
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.PFC;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PFC > 0.)
                total_PFC += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PFC;

        total_NMVOC = theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.NMVOC/theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.NMVOC
                + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.NMVOC;
        if (theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NMVOC > 0.)
                total_NMVOC += theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NMVOC;

        report_->htmlReportStream()
                << html::h2("Life Cycle Emissions of one aircraft")
                << "<br>"
                << html::h3("All Phases")
                << "<br>";
        report_->htmlReportStream() << html::table_begin({{"Parameter"},
                                        {"Development", "colspan=\"2\""},
                                        {"Production", "colspan=\"2\""}, {"Operation", "colspan=\"2\""},
                                        {"End of Life", "colspan=\"2\""}})
        << html::table_row("", "[t]", "[%]", "[t]", "[%]", "[t]", "[%]", "[t]", "[%]")
        << html::table_row("CO2",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO2 / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO2 / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_CO2 * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO2 / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO2 / total_CO2 * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO2 / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO2 / total_CO2 * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO2 / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO2 / total_CO2 * 100)
        << html::table_row("H2O",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.H2O / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.H2O / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_H2O * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.H2O / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.H2O / total_H2O * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.H2O / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.H2O / total_H2O * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.H2O / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.H2O / total_H2O * 100)
        << html::table_row("SO2",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.SO2 / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.SO2 / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_SO2 * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.SO2 / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.SO2 / total_SO2 * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.SO2 / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.SO2 / total_SO2 * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.SO2 / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.SO2 / total_SO2 * 100)
        << html::table_row("HC",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.HC / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.HC / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_HC * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.HC / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.HC / total_HC * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.HC / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.HC / total_HC * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.HC / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.HC / total_HC * 100)
        << html::table_row("CH4",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CH4 / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CH4 / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_CH4 * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CH4 / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CH4 / total_CH4 * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CH4 / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CH4 / total_CH4 * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CH4 / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CH4 / total_CH4 * 100)
        << html::table_row("NOx",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.NOx / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.NOx / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_NOx * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.NOx / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.NOx / total_NOx * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.NOx / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.NOx / total_NOx * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NOx / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NOx / total_NOx * 100)
        << html::table_row("CO",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_CO * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO / total_CO * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO / total_CO * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO / total_CO * 100)
        << html::table_row("PM10",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.PM10 / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.PM10 / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_PM10 * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.PM10 / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.PM10 / total_PM10 * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.PM10 / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.PM10 / total_PM10 * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PM10 / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PM10 / total_PM10 * 100)
        << html::table_row("N2O",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.N2O / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.N2O / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_N2O
                * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.N2O / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.N2O / total_N2O * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.N2O / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.N2O / total_N2O * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.N2O / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.N2O / total_N2O * 100)
        << html::table_row("PFC",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.PFC / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.PFC / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / total_PFC
                * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.PFC / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.PFC / total_PFC * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.PFC / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.PFC / total_PFC * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PFC / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PFC / total_PFC * 100)
        << html::table_row("NMVOC",
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.NMVOC / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft / 1000,
                theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.NMVOC / theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.number_produced_aircraft
                / total_NMVOC * 100,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.NMVOC / 1000,
                theLifeCycleEmissionsSchaefer.theProduction.productionTotal.NMVOC / total_NMVOC * 100,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.NMVOC / 1000,
                theLifeCycleEmissionsSchaefer.theOperation.operationTotal.NMVOC / total_NMVOC * 100,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NMVOC / 1000,
                theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NMVOC / total_NMVOC * 100)
        << "</tbody>" << "\n"
        << html::table_end;
        report_->htmlReportStream() << "<br>" << "\n"<< "<br>" << "\n";
        if (rtIO->plotOn) {
          report_->htmlReportStream()
               << html::image(relativePath(rtIO->getPlotDir() + FILESEPERATOR + std::string(TOOL_NAME) + "_life_cycle_emissions.svg", rtIO->getHtmlDir(), false), "");
        }
}

void StandardStrategy::set_tex_body_LCA_schaefer(const std::shared_ptr<RuntimeIO> &rtIO) {
        // TODO
}



void StandardStrategy::generate_life_cycle_emissions_csv_schaefer() {
     std::ofstream csv;
     std::string csvDataFile(rtIO->getCsvFilesDir() + "/ecological_assessment_life_cycle_emissions.csv");
     csv.open(csvDataFile.c_str());
     if (!csv) {
          myRuntimeInfo->err << csvDataFile + "could not be opened!" << std::endl;
          exit(1);
     } else {
          std::string del("; ");
          csv << "# " + csvDataFile << std::endl;
          csv << "# all emission data in [kg]; Energy in [MJ], AC Fuel in [kg] (without logistics fuel, only fuel of the investigated AC)" << std::endl;
          /* Adjust data structure: **/
          csv << std::endl << std::endl;
          csv << "# Development Phase (NOT for one AC but for total Development phase) " << std::endl;
          csv << "# (1)EmissionName; (2)CO2; (3)H2O; (4)NOx; (5)CO; (6)SO2; (7)CH4; (8)PM10; (9)N2O; (10)PFC; (11)NMVOC; (12)HC; (13) Energy; (14) AC Fuel; (15) GWP100" <<
             std::endl;//GWP after CML2015, IPCC value
          csv << "Development_total" << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO2
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.H2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.NOx
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CH4
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.PM10<< del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.N2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.NMVOC
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.HC << del <<  theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CED
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.fuel_total << del
               << theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.developmentTotal.CH4 * 25 << std::endl;
          csv << "Engineering_total" << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.CO2
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.H2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.CO
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.CH4
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.N2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.NMVOC
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.CED
               << del << 0.
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.engineeringTotal.CH4 * 25 << std::endl;
          csv << "EngineeringElec" << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.CO2
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.H2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.CO
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.CH4
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.N2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.NMVOC
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.CED << del << 0.
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.engineeringElectricity.CH4 * 25 << std::endl;
          csv << "EngineeringHeat" << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.CO2
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.H2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.CO
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.CH4
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.N2O
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.NMVOC
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.CED
               << del << 0.
               << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.engineeringHeat.CH4 * 25 << std::endl;
          /*csv << "TestFueLProduction" << del << testFuelProduction.CO2 << del << testFuelProduction.H2O << del <<
               testFuelProduction.NOx << del << testFuelProduction.CO << del << testFuelProduction.SO2 << del <<
               testFuelProduction.CH4 << del << testFuelProduction.PM10 << del << testFuelProduction.N2O << del <<
               testFuelProduction.PFC << del << testFuelProduction.NMVOC << del << testFuelProduction.HC << std::endl;*/
          csv << "TestTotal" << del << theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.CO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.PFC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.HC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.CED << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testResources.fuel_test_total << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.testTotal.CH4 * 25 << std::endl;
          csv << "WindTunnelTests" << del << theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.windTunnelTests.CH4 * 25 << std::endl;
          csv << "StructureTests" << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.CED << del << 0. <<  del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.structureTests.CH4 * 25 << std::endl;
          csv << "SystemTests" << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.CH4 << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.N2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.PFC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.NMVOC << del << theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.HC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.CED  << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.systemTests.CH4 * 25 << std::endl;
          csv << "GroundTests (incl. Fuel Prod.)" << del << theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.NOx << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.PFC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.HC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.CED << del <<
               theDesignMission.fuel_mass_taxi *theLifeCycleEmissionsSchaefer.theDevelopment.taxi_fuel_test_factor << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.groundTests.CH4 * 25 << std::endl;
          if (theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.do_engine_tests) {
               csv << "EngineTests " << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.CO2 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.H2O << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.NOx << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.CO << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.SO2 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.CH4 << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.PM10 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.N2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.PFC << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.NMVOC << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.HC << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.CED << del << theLifeCycleEmissionsSchaefer.theDevelopment.testResources.fuel_engine_test_total
                    << del << theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.engineTests.CH4 * 25 << std::endl;
          }
          csv << "FlightTests (incl. Fuel Prod.)" << del << theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.NOx << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.CH4 << del << theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.N2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.PFC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.NMVOC << del << theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.HC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.CED << del << theLifeCycleEmissionsSchaefer.theDevelopment.testResources.fuel_flight_test << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.flightTests.CH4 * 25 << std::endl;
          csv << "ProductionTestAircraft" << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.H2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.NOx << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.CO << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.SO2 << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.PM10 << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.N2O << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.PFC << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.HC << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.productionTestAircraft.CH4 * 25 << std::endl;
          if (theLifeCycleEmissionsSchaefer.schaeferIOData->configuration.do_engine_tests) {
               csv << "ProductionTestEngine" << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.CO2 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.H2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.NOx << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.CO << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.SO2 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.CH4 << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.PM10 << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.N2O << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.PFC << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.NMVOC << del << theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.HC << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.CED << del << 0. << del <<
                    theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.CO2 + theLifeCycleEmissionsSchaefer.theDevelopment.productionTestEngine.CH4 * 25 << std::endl;
          }
          csv << std::endl << std::endl;
          csv << "# Production Phase " << std::endl;
          csv << "# (1)EmissionName; (2)CO2; (3)H2O; (4)NOx; (5)CO; (6)SO2; (7)CH4; (8)PM10; (9)N2O; (10)PFC;"
                    " (11)NMVOC; (12)HC; (13) Energy; (14) AC Fuel; (15) GWP100" << std::endl;
          csv << "Production_total" << del << theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.productionTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.productionTotal.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.productionTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.productionTotal.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.productionTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.productionTotal.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.productionTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.productionTotal.HC << del << theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CED << del <<
               theLifeCycleEmissionsSchaefer.theProduction.test_flight_fuel  << del <<
               theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CO2 + theLifeCycleEmissionsSchaefer.theProduction.productionTotal.CH4 * 25 << std::endl;
          csv << "MaterialProduction" << del << theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.CO2 + theLifeCycleEmissionsSchaefer.theProduction.materialProductionTotal.CH4 * 25
               << std::endl;
          csv << "MaterialProcessing" << del << theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.H2O << del << theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.CO << del << theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.CO2 + theLifeCycleEmissionsSchaefer.theProduction.materialProcessingTotal.CH4 * 25
               << std::endl;
          csv << "LabourProductionTotal" << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.CO2 + theLifeCycleEmissionsSchaefer.theProduction.labourProductionTotal.CH4 * 25 << std::endl;
          csv << "LabourProductionElectricity" << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.CO2 << del <<
          theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.CO2 + theLifeCycleEmissionsSchaefer.theProduction.labourProductionElectricity.CH4 * 25 << std::endl;
          csv << "LabourProductionHeat" << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.CO2 << del <<
          theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.HC << del << theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.CED << del <<
               0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.CO2 + theLifeCycleEmissionsSchaefer.theProduction.labourProductionHeat.CH4 * 25 << std::endl;
          csv << "FinalAssemblyTotal" << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.CO2 + theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyTotal.CH4 * 25 << std::endl;
          csv << "FinalAssemblyElectricity" << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.HC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.CO2 + theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyElectricity.CH4 * 25 << std::endl;
          csv << "FinalAssemblyHeat" << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.NOx << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.SO2 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.PM10 << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.PFC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.HC << del << theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.CO2 + theLifeCycleEmissionsSchaefer.theProduction.finalAssemblyHeat.CH4 * 25 << std::endl;
          csv << "Transport (incl. Fuel Prod.)" << del << theLifeCycleEmissionsSchaefer.theProduction.transport.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.H2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.CO << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.N2O << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.NMVOC << del << theLifeCycleEmissionsSchaefer.theProduction.transport.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theProduction.transport.CO2 + theLifeCycleEmissionsSchaefer.theProduction.transport.CH4 * 25 << std::endl;
          csv << "FinalTestFlights (incl. Fuel Prod." << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.H2O << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.NOx << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CO << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CH4 << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.N2O << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.PFC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.NMVOC << del << theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.HC << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CED << del << theLifeCycleEmissionsSchaefer.theProduction.test_flight_fuel << del <<
               theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CO2 + theLifeCycleEmissionsSchaefer.theProduction.finalFlightTests.CH4 * 25 << std::endl;
          /*csv << "Finaltest_flight_fuelProd" << del << finalTestFlightFuelProduction.CO2 << del << finalTestFlightFuelProduction.H2O << del <<
               finalTestFlightFuelProduction.NOx << del << finalTestFlightFuelProduction.CO << del << finalTestFlightFuelProduction.SO2 << del <<
               finalTestFlightFuelProduction.CH4 << del << finalTestFlightFuelProduction.PM10 << del << finalTestFlightFuelProduction.N2O << del <<
               finalTestFlightFuelProduction.PFC << del << finalTestFlightFuelProduction.NMVOC << del <<
               finalTestFlightFuelProduction.HC << del << 0. << del << 0. << std::endl;*/
          csv << std::endl << std::endl;
          csv << "# Operation Phase " << std::endl;
          csv << "# (1)EmissionName; (2)CO2; (3)H2O; (4)NOx; (5)CO; (6)SO2; (7)CH4; (8)PM10; (9)N2O; (10)PFC; (11)NMVOC;"
                    " (12)HC; (13) Energy; (14) AC Fuel; (15) GWP100" << std::endl;
          csv << "Operation_total" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operationTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationTotal.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationTotal.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.operationTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationTotal.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.operationTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationTotal.HC << del << theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CED << del <<
               theLifeCycleEmissionsSchaefer.theOperation.missions_fuel << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CO2 + theLifeCycleEmissionsSchaefer.theOperation.operationTotal.CH4 * 25 << std::endl;
          csv << "Operation Fuel Missions" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.missions.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.missions.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.missions.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.missions.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.missions.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.missions.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.missions.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.missions.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.missions.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.missions.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.missions.HC << del << 0. << del << theLifeCycleEmissionsSchaefer.theOperation.missions_fuel << del <<
               theLifeCycleEmissionsSchaefer.theOperation.missions.CO2 + theLifeCycleEmissionsSchaefer.theOperation.missions.CH4 * 25 << std::endl;
          csv << "FuelProd Missions" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.HC << del << theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CED << del <<
               0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CO2 + theLifeCycleEmissionsSchaefer.theOperation.operationFuelProduction.CH4 * 25 << std::endl;
          csv << "MaintenanceLabour" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.HC << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.CO2 + theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourTotal.CH4 * 25 << std::endl;
          csv << "MaintenanceLabour_elec" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.HC << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.CO2 + theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourElectricity.CH4 * 25 << std::endl;
          csv << "MaintenanceLabour_heat" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.HC << del << theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.CO2 + theLifeCycleEmissionsSchaefer.theOperation.maintenanceLabourHeat.CH4 * 25 << std::endl;
          csv << "SparePartsTotal" << del <<
               theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.CO2 << del << theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.NOx << del << theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.PM10 << del << theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.PFC << del << theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.HC << del << theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.CO2 + theLifeCycleEmissionsSchaefer.theOperation.sparePartsTotal.CH4 * 25 << std::endl;
          csv << std::endl << std::endl;
          csv << "# End-of-Life Phase " << std::endl;
          csv << "# (1)EmissionName; (2)CO2; (3)H2O; (4)NOx; (5)CO; (6)SO2; (7)CH4; (8)PM10; (9)N2O; (10)PFC; (11)NMVOC;"
                    " (12)HC; (13) Energy; (14) AC Fuel; (15) GWP100" << std::endl;
          csv << "EndOfLifeTotal" << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PM10 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.PFC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.HC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CED << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.transport_fuel << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CO2 + theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTotal.CH4 * 25 << std::endl;
          csv << "Transport (incl. Fuel Prod.)" << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.CO << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.SO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.PM10 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.N2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.PFC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.HC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.CED << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.transport_fuel << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.CO2 + theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeTransport.CH4 * 25 << std::endl;
          /*csv << "Transport Fuel Production" << del << theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.CO << del << theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.SO2 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.CH4 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.PM10 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.N2O << del << theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.PFC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.NMVOC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.HC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.end_of_life_transport_fuelProduction.CED << del << 0. << std::endl;*/
          csv << "Disass. and Dismantling" << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.CO << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.SO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.PM10 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.N2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.PFC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.HC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.CO2 + theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeDD.CH4 * 25 << std::endl;
          csv << "EoL Scen. Total" << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.CO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.H2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.NOx << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.CO << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.SO2 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.CH4 << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.PM10 << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.N2O << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.PFC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.NMVOC << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.HC << del << theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.CED << del << 0. << del <<
               theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.CO2 + theLifeCycleEmissionsSchaefer.theEndOfLife.endOfLifeMaterialTotal.CH4 * 25 << std::endl;
          csv << std::endl << std::endl;
          csv.close();
     }
}


