/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "missionConfig.h"
#include <aixml/node.h>

using std::string;

MissionConfig::MissionConfig()
    :
    kerosene_method_HC(""),
    kersosene_method_CO(""),
    kerosene_method_NOx(""),
    kerosene_method_soot(""),
    relative_humidity(0.) {}

void MissionConfig::read_all_config_data(const node& configXML) {
    const node& mission(configXML.at("program_settings/standard_strategy/emission_calculation/mission_emissions"));

    kerosene_method_HC = EndnodeReadOnly<string>("emission_methods/kerosene/HC_method_selector").read(mission).value();
    kersosene_method_CO = EndnodeReadOnly<string>("emission_methods/kerosene/CO_method_selector").read(mission).value();
    kerosene_method_NOx = EndnodeReadOnly<string>("emission_methods/kerosene/NOx_method_selector").read(mission).value();
    kerosene_method_soot = EndnodeReadOnly<string>("emission_methods/kerosene/soot_method_selector").read(mission).value();
    hydrogen_method_NOx = EndnodeReadOnly<string>("emission_methods/hydrogen_combustion/NOx_method_selector").read(mission).value();
    relative_humidity = EndnodeReadOnly<double>("relative_humidity").read(mission).value();
}

MissionConfig::~MissionConfig() {
    //dtor
}

