/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef VOLUME_COEFFICIENT_METHOD_H_
#define VOLUME_COEFFICIENT_METHOD_H_

#include <aircraftGeometry2/geometry/factory.h>
#include <aircraftGeometry2/io/dat.h>
#include <aircraftGeometry2/processing/transform.h>

#include <Eigen/Dense>
#include <tuple>

class VolumeCoefficientMethod {
 public:
  VolumeCoefficientMethod() = default;

  void compute_geometry(int number_of_tails, double volume_coefficient, double sweep, double taper_ratio,
                        double aspect_ratio, double reference_area, double reference_length, double fuselage_length,
                        geom2::Point_3& reference_neutral_point, geom2::Point_3& offset_position,
                        geom2::Direction_3 orientation, bool symmetric);
  void compute_geometry(int number_of_tails, double volume_coefficient, double sweep, double taper_ratio,
                        double root_chord, double wing_area, double wing_span,
                        geom2::Point_3& wing_neutral_point_position, geom2::Point_3& reference_position,
                        bool symmetric);

  geom2::MultisectionSurface<geom2::AirfoilSection> get_design(geom2::AirfoilSection root_profile,
                                                               geom2::AirfoilSection tip_profile,
                                                               const double dihedral);

  double root_chord{0.};
  double tip_chord{0.};
  double span{0.};
  double sweep{0.};
  int span_multiplier{2};

  geom2::Point_3 origin{geom2::Point_3(0., 0., 0.)};
  geom2::Direction_3 orientation{geom2::Direction_3(0., 0., 1.)};
  geom2::MultisectionSurface<geom2::AirfoilSection> surface;
};

#endif  // VOLUME_COEFFICIENT_METHOD_H_