/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef PLOT_UTILITY_H_
#define PLOT_UTILITY_H_

#include <aircraftGeometry2/processing/measure.h>
#include <aircraftGeometry2/processing/transform.h>

#include <algorithm>
#include <map>
#include <array>
#include <utility>
#include <cmath>

/**
 * \brief Generate polygon from spar or controldevice
 *
 * \param surface aerodynamic surface object
 * \param object spar or control device object
 * \return std::tuple<std::vector<double>,std::vector<double>,std::string> coordinates and object name
 */
std::tuple<std::vector<double>, std::vector<double>, std::string> gen_polygon(
    const geom2::MultisectionSurface<geom2::AirfoilSection>& surface,
    const geom2::MultisectionSurface<geom2::PolygonSection>& object);

std::array<float, 4UL> get_spar_colors();

std::array<float, 4UL> get_control_device_colors(const std::string& control_device);

#endif // PLOT_UTILITY_H_
