/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include <string>
#include <vector>
#include <memory>
#include <filesystem>
#include <map>

#include <moduleBasics/strategySelector.h>
#include "initialSizing.h"
#include "taw/analytical/TawAnalytical.h"
#include "taw/database/data_interpolated/TawInitialSizingInt.h"
#include "taw/database/data_reference/TawInitialSizingRef.h"
#include "bwb/analytical/BwbAnalytical.h"

namespace fs = std::filesystem;

initialSizing::initialSizing(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion): Module(argc, argv, toolName, toolVersion) {
  rtIO_ = get_RuntimeIO();
  std::string configuration = rtIO_->aircraft_configuration_type();
  std::string approach = rtIO_->moduleConfig.at("program_settings/approach_selection/value");
  route = {configuration, approach};
  strategy_.setStrategy(routing_(route)(rtIO_));
}

strategyaccess initialSizing::routing_(const std::vector<std::string> &route) {
    /* Routing table */
    std::map<std::string, std::map<std::string, strategyaccess>> table = {
        {"tube_and_wing",
            std::map<std::string, strategyaccess>{
                {"analytical",
                    [](const std::shared_ptr<RuntimeIO> &arg) {
                        return std::make_unique<TawAnalytical>(arg);
                    }},
            }},
    };

    return table[route.at(0)][route.at(1)];
}
