/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 * 
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */
#ifndef PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_ENGINEPERFORMANCE_LOW_FIDELITY_ENGINEPERFORMANCE_H_
#define PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_ENGINEPERFORMANCE_LOW_FIDELITY_ENGINEPERFORMANCE_H_

#include <vector>
#include <string>
#include <memory>

#include "../../aircraft.h"
#include "../abstractEnginePerformance.h"

using std::vector;
using std::string;

namespace low {

/**\class enginePerformance Global class that contains performances of the engine
*
*/
class enginePerformance : public abstractEnginePerformance{
 public:
    double maxThrust; /** Maximum thrust of the aircraft (N) */

    /** \brief Calculates the aircraft engine performance for different engine ratings
    * \param theRating vector with engine rating
    */
    void doEngineCalculation(vector<string> theRating);

    /** \brief Constructor enginePerformance
    * \param theAircraft Address to the aircraft object
    */
    explicit enginePerformance(std::shared_ptr<aircraft> theAircraftPt);

    /**\brief Destructor enginePerformance
    *
    */
    virtual ~enginePerformance();

 private:
    std::shared_ptr<aircraft> theAircraftPt; /**< Pointer to the aircraft object */

    /**\brief Function to get the maximum thrust
    * \return Maximum thrust (N)
    */
    double getMaxThrust();
};

}  // namespace low
#endif  // PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_ENGINEPERFORMANCE_LOW_FIDELITY_ENGINEPERFORMANCE_H_
