/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 * 
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */
#ifndef PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_PAYLOADRANGE_LOW_FIDELITY_PAYLOADRANGE_H_
#define PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_PAYLOADRANGE_LOW_FIDELITY_PAYLOADRANGE_H_

#include <unitConversion/unitConversion.h>

#include <vector>

// #include <runtimeInfo/runtimeInfo.h>

#include "../abstractPayloadRange.h"

#include "../../aircraft.h"
#include "../../performance_assessment_settings.h"

using std::vector;

namespace low {

/**\class payloadRange class contains the payload range diagram data
*
*/
class payloadRange : public abstractPayloadRange {
 public:
    // vector<double> Payload; /**< List of payloads (kg) */
    // vector<double> Fuel; /**< List of fuel masses (kg) */
    // vector<double> TOM; /**< List of take-off masses (kg) */
    // vector<double> Range; /**< List of aircraft ranges (km) */

    /**\brief Function that calculates the payload range
    *
    */
    void calcPayloadRange();

    /**\brief Constructor payloadRange
    *\param theAircraft Address to the aircraft object
    *\param theSettings Address to the performance_assessmentSettings object
    */
    payloadRange(aircraft *theAircraft, const performance_assessment_settings &theSettings);

    /**\brief Destructor payloadRange
    *
    */
    virtual ~payloadRange();

 private:
    aircraft *theAcftPt; /**< Pointer to the aircraft object */
    const performance_assessment_settings *theSettingsPt; /**< Pointer to the performance_assessmentSettings object */
};

};  // namespace low

#endif  // PERFORMANCE_ASSESSMENT_SRC_TAW_DEFAULTMETHODS_PAYLOADRANGE_LOW_FIDELITY_PAYLOADRANGE_H_
