/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_TRANSMISSIONSHAFT_H_
#define SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_TRANSMISSIONSHAFT_H_

#include <string>

/** \brief contains all properties of the transmission shaft
 */
class TransmissionShaft {
 public:
    double Mass;/**< [kg] mass of the transmission shaft */
    double efficiencyFactor;/**< [-] efficiency factor of the transmission shaft */
    double rotationSpeedShaft;/**< [1/s] rotation speed of the transmission shaft */

    /** \brief calculates the transmission shaft mass
     *
     * \param deviceType string
     * \param wingSpan double: [m]
     * \return void
     *
     */
    void getMass(const std::string& deviceType, double wingSpan);

    explicit TransmissionShaft(const std::string& Type);
    virtual ~TransmissionShaft();
};

#endif // SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_TRANSMISSIONSHAFT_H_
