/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "wingTipBrakes.h"

#include <cmath>

#include <runtimeInfo/runtimeInfo.h>

wingTipBrakes::wingTipBrakes()
    :
    Mass(0.0) {
    //ctor
}

wingTipBrakes::~wingTipBrakes() {
    //dtor
}

void wingTipBrakes::getMass(const std::string& deviceType, double installedPCUPower) {
    if (deviceType == "Slat" || deviceType == "Fowler" || deviceType == "flap_fowler") {
        // NOTE (aigner#1#): Methode geaendert von Lammering in rev2131 im Maerz 2013
        Mass = 2. * 3.4763 * pow(2.71828, (0.014077 * installedPCUPower / 1000.));
    } else {
        myRuntimeInfo->err << "The system type \"" << deviceType << "\" is unknown. wing tip brake mass cannot be calculated!" << std::endl;
        myRuntimeInfo->err << "Abort!" << std::endl;
        exit(1);
    }
}
