/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2025 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef WINGDESIGN_SRC_TAW_TAWWINGDESIGNCONFIG_H_
#define WINGDESIGN_SRC_TAW_TAWWINGDESIGNCONFIG_H_

#include <aixml/endnode.h>

#include <map>
#include <set>

#include "lib/io_methods/controlDeviceIO.h"
#include "lib/io_methods/sparIO.h"

namespace taw {
namespace cantilever_backward {

#include <aixml/endnode.h>

class WingDesignConfig {
 public:
  WingDesignConfig();
  ~WingDesignConfig() = default;
  void read(const node& xml);

  /* Modes */
  EndnodeReadOnly<std::string> wing_design_mode;
  EndnodeReadOnly<std::string> wing_configuration_mode;
  EndnodeReadOnly<std::string> wing_mass_mode;
  /* Design */
  /* Data for method - wing area calculation */
  EndnodeReadOnly<std::string> wing_area_calculation_mode;
  EndnodeReadOnly<double> user_wing_area;

  /* Data for method - quarter chord sweep calculation */
  EndnodeReadOnly<std::string> sweep_calculation_mode;
  EndnodeReadOnly<double> user_sweep_angle_at_quarter_chord;
  EndnodeReadOnly<double> korn_technology_factor;
  EndnodeReadOnly<double> delta_drag_divergence_to_mach_design;

  /* Data for method - taper ratio calculation */
  EndnodeReadOnly<std::string> taper_ratio_calculation_mode;
  EndnodeReadOnly<double> user_taper_ratio;

  /* Data for method - aspect ratio calculation */
  EndnodeReadOnly<std::string> aspect_ratio_calculation_mode;
  EndnodeReadOnly<double> user_aspect_ratio;

  /* Data for method - dihedral calculation*/
  EndnodeReadOnly<std::string> dihedral_calculation_mode;
  EndnodeReadOnly<double> user_dihedral;
  EndnodeReadOnly<double> raymer_range_value;

  EndnodeReadOnly<std::string> relative_kink_position_calculation_mode;
  EndnodeReadOnly<double> user_relative_kink;
  EndnodeReadOnly<double> user_max_inner_trailing_edge_sweep;
  EndnodeReadOnly<double> track_based_initial_relative_kink;
  EndnodeReadOnly<double> track_based_max_inner_trailing_edge_sweep;

  /* Data for method - wing profile and thickness calculation */
  EndnodeReadOnly<std::string> wing_profile_and_thickness_calculation_mode;
  std::vector<EndnodeReadOnly<std::string>> user_wing_profiles;
  std::vector<EndnodeReadOnly<double>> user_thickness_to_chord;
  std::vector<EndnodeReadOnly<double>> user_eta;
  std::vector<std::tuple<double, double, std::string>> user_wing_profiles_and_thickness_vector;
  EndnodeReadOnly<std::string> torenbeek_jenkinson_wing_profile;
  EndnodeReadOnly<double> max_thickness_to_chord_ratio;
  EndnodeReadOnly<double> airfoil_critical_factor;

  /* Mass */


  // flops mass method
  EndnodeReadOnly<double> flops_fstrt;
  EndnodeReadOnly<double> flops_faert;
  EndnodeReadOnly<double> flops_fcomp;
  EndnodeReadOnly<double> flops_technology_factor;

  // chiozzotto wer mass method
  EndnodeReadOnly<double> chiozzotto_technology_factor;
  EndnodeReadOnly<std::string> chiozzotto_material;

  /* Data for method - control devices */
  EndnodeReadOnly<std::string> control_device_mode;
  std::vector<ControlDevice> user_defined_control_devices;
  EndnodeReadOnly<std::string> high_lift_device_type_leading_edge;
  EndnodeReadOnly<std::string> high_lift_device_type_trailing_edge;

  /* Data for method - spars */
  EndnodeReadOnly<std::string> spars_mode;
  std::vector<Spar> user_defined_spars;

  /* Additional paths */
  EndnodeReadOnly<std::string> common_airfoil_data_path;
};
}  // namespace cantilever
}  // namespace taw

#endif  // WINGDESIGN_SRC_TAW_TAWWINGDESIGNCONFIG_H_
